carbon-index
============

.. image:: https://travis-ci.org/yunstanford/carbon-index.svg?branch=master
    :alt: build status
    :target: https://travis-ci.org/yunstanford/carbon-index

.. image:: https://coveralls.io/repos/github/yunstanford/carbon-index/badge.svg?branch=master
    :alt: coverage status
    :target: https://coveralls.io/github/yunstanford/carbon-index?branch=master


An trie index for carbon cache. Support wildcard search in carbon cache.

